<?php
/*
 * leFooter Admin Settings
 */

class Settings_API_Tabs_WPLFTR_Plugin {
	
	/*
	 * For easier overriding we declared the keys
	 * here as well as our tabs array which is populated
	 * when registering settings
	 */
	private $general_settings_key = 'wplftr_general_settings';
	private $advanced_settings_key = 'wplftr_advanced_settings';
	private $plugin_options_key = 'wplftr_plugin_options';
	private $plugin_settings_tabs = array();
	
	/*
	 * Fired during plugins_loaded (very very early),
	 * so don't miss-use this, only actions and filters,
	 * current ones speak for themselves.
	 */
	function __construct() {
		add_action( 'init', array( &$this, 'wplftr_load_settings' ) );
		add_action( 'admin_init', array( &$this, 'wplftr_register_general_settings' ) );
		add_action('admin_init' , array(&$this,'on_load_page'));
		add_action( 'admin_menu', array( &$this, 'wplftr_add_admin_menus' ) );
		add_action('wp_footer' , array(&$this,'footer_css'), 99);
	}

	function on_load_page(){
		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script('wp-color-picker');
		wp_enqueue_script(
			'wplftr-js',
			WPLFTR_SCRIPTS . '/admin.js',
			array( 'jquery' ),
			'',
			true
		);
	}
	
	/*
	 * Loads both the general and advanced settings from
	 * the database into their respective arrays. Uses
	 * array_merge to merge with default values if they're
	 * missing.
	 */
	function wplftr_load_settings() {
		$this->general_settings = (array) get_option( $this->general_settings_key );
		// $this->advanced_settings = (array) get_option( $this->advanced_settings_key );
	}
	
	/*
	 * Registers the general settings via the Settings API,
	 * appends the setting to the tabs array of the object.
	 */
	function wplftr_register_general_settings() {
		$this->plugin_settings_tabs[$this->general_settings_key] = 'WP - leFooter Settings';
		
		register_setting( $this->general_settings_key, $this->general_settings_key );
		add_settings_section( 'location_section', 'General Settings', array( &$this, 'wplftr_section_position_desc' ), $this->general_settings_key );
		add_settings_field( 'location_option', 'Location', array( &$this, 'wplftr_checkbox_location_option' ), $this->general_settings_key, 'location_section' );
		add_settings_section( 'theme_option', ' ', array( &$this, 'wplftr_theme_general_option' ), $this->general_settings_key);
		add_settings_section( 'custom_section', ' ', array( &$this, 'wplftr_section_custom_theme_content' ), $this->general_settings_key );
		add_settings_section( 'custom_texture', ' ', array( &$this, 'wplftr_section_custom_theme_texture' ), $this->general_settings_key );
		add_settings_section( 'custom_animation', ' ', array( &$this, 'wplftr_section_custom_theme_animation' ), $this->general_settings_key );
	}

	
	/*
	 * Registers the advanced settings and appends the
	 * key to the plugin settings tabs array.
	 */
	// function wplftr_register_advanced_settings() {
	// 	$this->plugin_settings_tabs[$this->advanced_settings_key] = 'Statistic';
		
	// 	register_setting( $this->advanced_settings_key, $this->advanced_settings_key );
	// 	add_settings_section( 'section_advanced', 'Statistic', array( &$this, 'wplftr_section_advanced_desc' ), $this->advanced_settings_key );
	// 	add_settings_section( 'statistic', ' ', array( &$this, 'wplftr_section_statistic' ), $this->advanced_settings_key );
	// }
	
	/*
	 * The following methods provide descriptions
	 * for their respective sections, used as callbacks
	 * with add_settings_section
	 */
	function wplftr_section_position_desc() { 
		if(isset($_GET['settings-updated']) && $_GET['settings-updated'] == 'true') {
			$this->override_css();
		}
		?> 
		<table class="form-table">
			<tbody>
				<tr valign="top">
					<th scope="row"><label><?php _e('Inner Width', 'wplftr');?></label></th>
					<td>
						<input type="text" name="<?php echo $this->general_settings_key; ?>[width]" value="<?php echo $this->general_settings['width'];?>" /> px
					</td>
				</tr>
				<tr valign="top">
					<th scope="row"><label><?php _e('Responsive', 'wplftr');?></label></th>
					<td>
						<input type="checkbox" name="<?php echo $this->general_settings_key; ?>[responsive]" value="1" <?php echo ( isset($this->general_settings['responsive']) ) ? 'checked=""checked' : ''; ?> /> <small><?php _e('Remove slide-up & turn to normal footer widgets on browser width less than 768px only.', 'wplftr');?></small><br />
					</td>
				</tr>
				<tr valign="top">
					<th scope="row"><label><?php _e('Auto Open', 'wplftr');?></label></th>
					<td>
						<input type="checkbox" name="<?php echo $this->general_settings_key; ?>[open]" value="1" <?php echo ( isset($this->general_settings['open']) ) ? 'checked=""checked' : ''; ?> /> <small><?php _e('Automatically Slide Up when page loaded.', 'wplftr');?></small><br />
					</td>
				</tr>
			</tbody>
		</table><br />
	<?php echo 'Please select the locations that you wish to allow the WP-leFooter to show.'; }
	function wplftr_section_custom_theme_content() { ?>
		<div id="wplftr-custom-theme">
			<h3><?php _e('Custom Color Scheme', 'wplftr');?></h3>
			<?php _e('Create your own WP-leFooter color scheme by using the following options.', 'wplftr');?>
			<div style="clear:both;"></div>
			<div style="float:left;width:440px;">
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row"><label><?php _e('Toggle Opener Background','wplftr');?></label></th>
							<td><input type="text" id="coloropener" name="<?php echo $this->general_settings_key; ?>[coloropener]" class="wplftr-color" value="<?php echo (!empty($this->general_settings['coloropener'])) ? $this->general_settings['coloropener'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label><?php _e('Inner Background', 'wplftr');?></label></th>
							<td><input type="text" id="colorbg" name="<?php echo $this->general_settings_key; ?>[colorbg]" class="wplftr-color" value="<?php echo (!empty($this->general_settings['colorbg'])) ? $this->general_settings['colorbg'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label><?php _e('Headings', 'wplftr');?></label></th>
							<td><input type="text" id="colorhead" name="<?php echo $this->general_settings_key; ?>[colorhead]" class="wplftr-color" value="<?php echo (!empty($this->general_settings['colorhead'])) ? $this->general_settings['colorhead'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label><?php _e('Links', 'wplftr');?></label></th>
							<td><input type="text" id="colorlink" name="<?php echo $this->general_settings_key; ?>[colorlink]" class="wplftr-color" value="<?php echo (!empty($this->general_settings['colorlink'])) ? $this->general_settings['colorlink'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label><?php _e('Paragraph', 'wplftr');?></label></th>
							<td><input type="text" id="colorp" name="<?php echo $this->general_settings_key; ?>[colorp]" class="wplftr-color" value="<?php echo (!empty($this->general_settings['colorp'])) ? $this->general_settings['colorp'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label><?php _e('Lists', 'wplftr');?></label></th>
							<td><input type="text" id="colorlist" name="<?php echo $this->general_settings_key; ?>[colorlist]" class="wplftr-color" value="<?php echo (!empty($this->general_settings['colorlist'])) ? $this->general_settings['colorlist'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label><?php _e('Button Text', 'wplftr');?></label></th>
							<td><input type="text" id="colorbt" name="<?php echo $this->general_settings_key; ?>[colorbt]" class="wplftr-color" value="<?php echo (!empty($this->general_settings['colorbt'])) ? $this->general_settings['colorbt'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label><?php _e('Button Background', 'wplftr');?></label></th>
							<td><input type="text" id="colorb" name="<?php echo $this->general_settings_key; ?>[colorb]" class="wplftr-color" value="<?php echo (!empty($this->general_settings['colorb'])) ? $this->general_settings['colorb'] : ' ' ; ?>" /></td>
						</tr>
					</tbody>
				</table>
			</div>
			<div style="float:left; width:300px; padding-left:70px; padding-top:15px;">
				<div id="wplftr-picker"></div>
			</div>
			<div style="clear:both;"></div>
		</div>
	<?php }
	function wplftr_section_custom_theme_texture() { ?>
		<div id="wplftr-custom-texture">
			<h3><?php _e('Custom Background Texture', 'wplftr');?></h3>
			<?php _e('Enhance your WP - leFooter design by adding any of the following textures', 'wplftr');?>
			<div style="clear:both;"></div>
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row"><label><?php _e('Background Texture', 'wplftr');?></label></th>
							<td>
								<select name="<?php echo $this->general_settings_key; ?>[texture]"  >
									<option value=""><?php _e('Select Texture', 'wplftr');?></option>
									<option value="diagonal" <?php echo ($this->general_settings['texture']== "diagonal") ? 'selected=""selected' : ''; ?> ><?php _e('Diagonal Lines', 'wplftr');?></option>
									<option value="diamonds" <?php echo ($this->general_settings['texture']== "diamonds") ? 'selected=""selected' : ''; ?> ><?php _e('Diamonds', 'wplftr');?></option>
									<option value="noise" <?php echo ($this->general_settings['texture']== "noise") ? 'selected=""selected' : ''; ?> ><?php _e('Noise', 'wplftr');?></option>
									<option value="pixelated" <?php echo ($this->general_settings['texture']== "pixelated") ? 'selected=""selected' : ''; ?> ><?php _e('Pixelated', 'wplftr');?></option>
									<option value="scan-lines" <?php echo ($this->general_settings['texture']== "scan-lines") ? 'selected=""selected' : ''; ?> ><?php _e('Scan-Lines', 'wplftr');?></option>
								</select>
							</td>
						</tr>
					</tbody>
				</table>
			<div style="clear:both;"></div>
		</div>

		<div id="wplftr-custom-opener-position">
			<h3><?php _e('Toggle Opener Position', 'wplftr');?></h3>
			<?php _e('Change Toggle Opener Position to either Left, Center or Right', 'wplftr');?>
			<div style="clear:both;"></div>
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row"><label><?php _e('Position', 'wplftr');?></label></th>
							<td>
								<select name="<?php echo $this->general_settings_key; ?>[openerp]"  >
									<option value=""><?php _e('Select Position', 'wplftr');?></option>
									<option value="left" <?php echo ($this->general_settings['openerp']== "left") ? 'selected=""selected' : ''; ?> ><?php _e('Left', 'wplftr'); ?></option>
									<option value="center" <?php echo ($this->general_settings['openerp']== "center") ? 'selected=""selected' : ''; ?> ><?php _e('Center', 'wplftr'); ?></option>
									<option value="right" <?php echo ($this->general_settings['openerp']== "right") ? 'selected=""selected' : ''; ?> ><?php _e('Right', 'wplftr'); ?></option>
								</select>
							</td>
						</tr>
					</tbody>
				</table>
			<div style="clear:both;"></div>
		</div>

	<?php }

	function wplftr_section_advanced_desc() { echo 'Advanced section description goes here.'; }
	
	/*
	 * Pages you want the footer to appear
	 */
	function wplftr_checkbox_location_option() {
		// print_r( $this->general_settings );
		?>
		<input type="checkbox" id="wplftr-location-all" name="<?php echo $this->general_settings_key; ?>[location][all]" value="1" <?php echo ( isset($this->general_settings['location']['all']) ) ? 'checked=""checked' : ''; ?> /> <label for="wplftr-location-all"><?php _e('<strong>All Posts, Pages, Templates and Plugin Pages</strong> - <small> Display on any wordpress pages, this will override all individual locations below.</small>', 'wplftr');?></label><br />
		<input type="checkbox" id="wplftr-location-home" name="<?php echo $this->general_settings_key; ?>[location][home]" value="1" <?php echo ( isset($this->general_settings['location']['home']) ) ? 'checked=""checked' : ''; ?> /> <label for="wplftr-location-home"><?php _e('Home page - <small>The front page of the blog (if set to a static page), or the main blog page (if set to your latest posts).</small>', 'wplftr');?></label><br />
		<input type="checkbox" id="wplftr-location-blog" name="<?php echo $this->general_settings_key; ?>[location][blog]" value="1" <?php echo ( isset($this->general_settings['location']['blog']) ) ? 'checked=""checked' : ''; ?> /> <label for="wplftr-location-blog"><?php _e('Blog page - <small>The home page of the blog if is set to your latest posts, or the posts page if the home page is set to a static page</small>', 'wplftr');?></label><br />
		<input type="checkbox" id="wplftr-location-posts" name="<?php echo $this->general_settings_key; ?>[location][posts]" value="1" <?php echo ( isset($this->general_settings['location']['posts'] ) ) ? 'checked=""checked' : ''; ?> /> <label for="wplftr-location-posts"><?php _e('Posts - <small>Single post pages</small>', 'wplftr');?></label><br />
		<input type="checkbox" id="wplftr-location-pages" name="<?php echo $this->general_settings_key; ?>[location][pages]" value="1" <?php echo ( isset($this->general_settings['location']['pages']) ) ? 'checked=""checked' : ''; ?> /> <label for="wplftr-location-pages"><?php _e('Pages - <small>Individual Wordpress pages</small>', 'wplftr');?></label><br />
		<input type="checkbox" id="wplftr-location-products" name="<?php echo $this->general_settings_key; ?>[location][products]" value="1" <?php echo ( isset($this->general_settings['location']['products']) ) ? 'checked=""checked' : ''; ?> /> <label for="wplftr-location-products"><?php _e('Products - <small>WooCommerce Product pages (if installed)</small>', 'wplftr');?></label><br />
		<input type="checkbox" id="wplftr-location-category" name="<?php echo $this->general_settings_key; ?>[location][category]" value="1" <?php echo ( isset($this->general_settings['location']['category']) ) ? 'checked=""checked' : ''; ?> /> <label for="wplftr-location-category"><?php _e('Category archives - <small>Category archive pages</small>', 'wplftr');?></label><br />
		<input type="checkbox" id="wplftr-location-date" name="<?php echo $this->general_settings_key; ?>[location][date]" value="1" <?php echo ( isset($this->general_settings['location']['date']) ) ? 'checked=""checked' : ''; ?> /> <label for="wplftr-location-date"><?php _e('Date archives - <small>Date archive pages</small>', 'wplftr');?></label><br />
		<input type="checkbox" id="wplftr-location-tag" name="<?php echo $this->general_settings_key; ?>[location][tag]" value="1" <?php echo ( isset($this->general_settings['location']['tag']) ) ? 'checked=""checked' : ''; ?> /> <label for="wplftr-location-tag"><?php _e('Tag archives - <small>Tag archive pages</small>', 'wplftr');?></label><br />
		<input type="checkbox" id="wplftr-location-author" name="<?php echo $this->general_settings_key; ?>[location][author]" value="1" <?php echo ( isset($this->general_settings['location']['author']) ) ? 'checked=""checked' : ''; ?> /> <label for="wplftr-location-author"><?php _e('Author archives - <small>Author archive pages</small>', 'wplftr');?></label><br />
		<input type="checkbox" id="wplftr-location-search" name="<?php echo $this->general_settings_key; ?>[location][search]" value="1" <?php echo ( isset($this->general_settings['location']['search']) ) ? 'checked=""checked' : ''; ?> /> <label for="wplftr-location-search"><?php _e('Search results - <small>Search results pages</small>', 'wplftr');?></label><br />
		<?php
	}
	function wplftr_theme_general_option() {
		// print_r( $this->general_settings );
		?>
		<div id="wplftr-custom-theme-options">
			<h3><?php _e('Themes', 'wplftr');?></h3>
			<?php _e('Select from WP - leFooter awesome predefined themes', 'wplftr');?>
			<div style="clear:both;"></div>
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row"><label><?php _e('Themes', 'wplftr'); ?></label></th>
							<td>
								<select name="<?php echo $this->general_settings_key; ?>[theme]"  >
									<option value=""><?php _e('Select Theme', 'wplftr');?></option>
									<option value="minimalist-white" <?php echo ($this->general_settings['theme']== "minimalist-white") ? 'selected=""selected' : ''; ?> ><?php _e('Minimalist Light', 'wplftr');?></option>
									<option value="minimalist-dark" <?php echo ($this->general_settings['theme']== "minimalist-dark") ? 'selected=""selected' : ''; ?> ><?php _e('Minimalist Dark', 'wplftr');?></option>
									<option value="colored" <?php echo ($this->general_settings['theme']== "colored") ? 'selected=""selected' : ''; ?> ><?php _e('Colored', 'wplftr');?></option>
									<option value="gray" <?php echo ($this->general_settings['theme']== "gray") ? 'selected=""selected' : ''; ?> ><?php _e('Gray Block', 'wplftr');?></option>
									<option value="transparent" <?php echo ($this->general_settings['theme']== "transparent") ? 'selected=""selected' : ''; ?> ><?php _e('Transparent', 'wplftr');?></option>
								</select>
							</td>
						</tr>
					</tbody>
				</table>
			<div style="clear:both;"></div>
		</div>
		<?php
	}
	
	/*
	 * Animation speed and easing effect
	 */
	function wplftr_section_custom_theme_animation(){ 
		$easing = array('swing','easeInQuad','easeOutQuad','easeInOutQuad','easeInCubic','easeOutCubic','easeInOutCubic','easeInQuart','easeOutQuart','easeInOutQuart','easeInQuint','easeOutQuint','easeInOutQuint','easeInSine','easeOutSine','easeInOutSine','easeInExpo','easeOutExpo','easeInOutExpo','easeInCirc','easeOutCirc','easeInOutCirc','easeInElastic','easeOutElastic','easeInOutElastic','easeInBack','easeOutBack','easeInOutBack','easeInBounce','easeOutBounce','easeInOutBounce')
		?>
		<div id="wplftr-custom-theme-options">
			<h3><?php _e('Animation Settings' , 'wplftr');?></h3>
			<?php _e('Change animation speed and easing effect', 'wplftr');?>
			<div style="clear:both;"></div>
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row"><label><?php _e('Animation Speed' ,'wplftr');?></label></th>
							<td>
								<input type="text" name="<?php echo $this->general_settings_key; ?>[speed]" value="<?php echo $this->general_settings['speed'];?>" /> <?php _e('ms', 'wplftr');?>
							</td>
						</tr>
						<tr valign="top">
							<th scope="row"><label><?php _e('Easing Effect' ,'wplftr');?></label></th>
							<td>
								<select name="<?php echo $this->general_settings_key; ?>[easing]"  >
									<option value=""><?php _e('Select Effect', 'wplftr');?></option>
									<?php foreach ($easing as $key => $value) { ?>
									<option value="<?php echo $value;?>" <?php echo ($this->general_settings['easing']== $value) ? 'selected=""selected' : ''; ?> ><?php _e($value , 'wplftr');?></option>
									<?php } ?>
									
									</select>
							</td>
						</tr>
					</tbody>
				</table>
			<div style="clear:both;"></div>
		</div>
	<?php }
	/*
	 * Advanced Option field callback, same as above.
	 */
	function wplftr_field_advanced_option() {
		?>
		<input type="text" name="<?php echo $this->advanced_settings_key; ?>[advanced_option]" value="<?php echo esc_attr( $this->advanced_settings['advanced_option'] ); ?>" />
		<?php
	}
	
	/*
	 * Called during admin_menu, adds an options
	 * page under Settings called My Settings, rendered
	 * using the wplftr_plugin_options_page method.
	 */
	function wplftr_add_admin_menus() {
		add_options_page( 'WP-leFooter Setting', 'WP-leFooter Setting', 'manage_options', $this->plugin_options_key, array( &$this, 'wplftr_plugin_options_page' ) );
	}
	
	/*
	 * Plugin Options page rendering goes here, checks
	 * for active tab and replaces key with the related
	 * settings key. Uses the wplftr_plugin_options_tabs method
	 * to render the tabs.
	 */
	function wplftr_plugin_options_page() {
		$tab = isset( $_GET['tab'] ) ? $_GET['tab'] : $this->general_settings_key;
		?>
		<div class="wrap">
			<?php $this->wplftr_plugin_options_tabs(); ?>
			<form method="post" action="options.php">
				<?php wp_nonce_field( 'update-options' ); ?>
				<?php settings_fields( $tab ); ?>
				<?php do_settings_sections( $tab ); ?>
				<?php 
				if(function_exists('submit_button')) { submit_button(); } else { ?>
				<p class="submit"><input type="submit" name="submit" id="submit" class="button button-primary" value="Save Changes"></p>
				<?php }?>
			</form>
		</div>
		<?php
	}
	
	/*
	 * Renders our tabs in the plugin options page,
	 * walks through the object's tabs array and prints
	 * them one by one. Provides the heading for the
	 * wplftr_plugin_options_page method.
	 */
	function wplftr_plugin_options_tabs() {
		$current_tab = isset( $_GET['tab'] ) ? $_GET['tab'] : $this->general_settings_key;

		screen_icon();
		echo '<h2 class="nav-tab-wrapper">';
		foreach ( $this->plugin_settings_tabs as $tab_key => $tab_caption ) {
			$active = $current_tab == $tab_key ? 'nav-tab-active' : '';
			echo '<a class="nav-tab ' . $active . '" href="?page=' . $this->plugin_options_key . '&tab=' . $tab_key . '">' . $tab_caption . '</a>';	
		}
		echo '</h2>';
	}

	/*
	 * Create Separate Function for CSS params
	 * just in case the file is not writable, we can call it again
	 */

	function appearance_css(){
		$css = '';
		if(isset($this->general_settings['coloropener']) && !empty($this->general_settings['coloropener'])){
			$css .= 'body #leFooter #leFooter-content { border-color:'. $this->general_settings['coloropener'] .'; }';
			$css .= 'body #leFooter .le-opener{ background-color: '. $this->general_settings['coloropener'] .'; }';
		}
		if(isset($this->general_settings['colorbg']) && !empty($this->general_settings['colorbg'])){
			$css .= 'body #leFooter #leFooter-content{ background-color: '. $this->general_settings['colorbg'] .'; }';
		}
		if(isset($this->general_settings['texture']) && !empty($this->general_settings['texture'])){
			$css .= 'body #leFooter #leFooter-content{ background-image: url(' . WPLFTR_IMG . '/' . $this->general_settings['texture'] .'.png);
				background-repeat: repeat; }';
		}
		if(isset($this->general_settings['colorhead']) && !empty($this->general_settings['colorhead'])){
			$css .= 'body #leFooter #leFooter-content #leFooter-inner h1, 
			body #leFooter #leFooter-content #leFooter-inner h2, 
			body #leFooter #leFooter-content #leFooter-inner h3, 
			body #leFooter #leFooter-content #leFooter-inner h4, 
			body #leFooter #leFooter-content #leFooter-inner h5, 
			body #leFooter #leFooter-content #leFooter-inner h6{ color: '. $this->general_settings['colorhead'] .'; }';
		}
		if(isset($this->general_settings['colorlink']) && !empty($this->general_settings['colorlink'])){
			$css .= '#leFooter #leFooter-inner a{ color: '. $this->general_settings['colorlink'] .'; }';
		}
		if(isset($this->general_settings['colorp']) && !empty($this->general_settings['colorp'])){
			$css .= '#leFooter #leFooter-inner, #leFooter #leFooter-inner p{ color: '. $this->general_settings['colorp'] .'; }';
		}
		if(isset($this->general_settings['colorlist']) && !empty($this->general_settings['colorlist'])){
			$css .= '#leFooter #leFooter-inner .widget ul li{ color: '. $this->general_settings['colorlist'] .'; }';
		}
		if(isset($this->general_settings['colorb']) && !empty($this->general_settings['colorb'])){
			$css .= '#leFooter #leFooter-inner input[type="submit"], #leFooter #leFooter-inner button{ background-color: '. $this->general_settings['colorb'] .'; }';
		}
		if(isset($this->general_settings['colorbt']) && !empty($this->general_settings['colorbt'])){
			$css .= '#leFooter #leFooter-inner input[type="submit"], #leFooter #leFooter-inner button{ color: '. $this->general_settings['colorbt'] .' }';
		}

		return $css;
	}

	function override_css(){
		$path = plugin_dir_path(__FILE__) . '../css/custom.css';
		$options = "/********* Do not edit this file *********/\n\n";
		if(is_writable($path)){
			$options .= $this->appearance_css();
			$makecss = file_put_contents( $path , $options);
		}
		
	}

	function footer_css(){
		$path = plugin_dir_path(__FILE__) . '../css/custom.css';
		if(!is_writable($path)){
			echo '<style type="text/css">';
			echo $this->appearance_css();
			echo '</style>';
		}
	}
};

// Initialize the plugin
add_action( 'plugins_loaded', create_function( '', '$settings_api_tabs_wplftr_plugin = new Settings_API_Tabs_WPLFTR_Plugin;' ) );

?>