<?php
/*
 * Create Custom Widget Sidebar
 */
class WP_leFooter_Widgets {
    public function __construct() {
        add_action( 'wp_loaded', array( &$this,'register_sidebar') );
        add_action('admin_print_styles-widgets.php', array( &$this,'print_style'));
        add_filter('dynamic_sidebar_params', array( &$this,'add_classes_to_widget')); 
        if ( is_admin() ){
            add_action( 'sidebar_admin_setup', array( &$this,'expand_control') );
            add_filter( 'widget_update_callback', array( &$this,'ajax_update_callback'), 10, 3);   
        }
    }
    /**
     * Register Custom Widget Sidebar 
     */
    function register_sidebar(){
        register_sidebar(array(
          'name' => __( 'leFooter Widgets' ),
          'id' => 'lefooter-sidebar',
          'description' => __( 'Widgets in this area will be shown on the slideUp Footer.' ),
          'before_widget' => '<li id="%1$s" class="widget %2$s">',
          'after_widget'  => '</li>'
        ));
    }
    /**
     * Called on 'sidebar_admin_setup'
     * adds in the admin control per widget, but also processes import/export
     */
    function expand_control()
    {   
        global $wp_registered_widgets, $wp_registered_widget_controls;

        // ADD EXTRA FIELD TO EACH WIDGET CONTROL
        // pop the widget id on the params array (as it's not in the main params so not provided to the callback)
        foreach ( $wp_registered_widgets as $id => $widget )
        {   // controll-less widgets need an empty function so the callback function is called.
            if (!$wp_registered_widget_controls[$id])
                wp_register_widget_control($id,$widget['name'], 'wplftr_empty_control');
            $wp_registered_widget_controls[$id]['callback_wplefooter_redirect'] = $wp_registered_widget_controls[$id]['callback'];
            $wp_registered_widget_controls[$id]['callback'] = array( &$this,'extra_control');
            array_push( $wp_registered_widget_controls[$id]['params'], $id );   
        }

    }

    /*
     * added to widget functionality in 'expand_control'
     */
    function empty_control() {}

    /*
     * added to widget functionality in 'expand_control'
     */
    function extra_control()
    {   
        global $wp_registered_widget_controls;

        $params = func_get_args();
        $id = array_pop($params);

        // go to the original control function
        $callback = $wp_registered_widget_controls[$id]['callback_wplefooter_redirect'];
        if ( is_callable($callback) )
            call_user_func_array($callback, $params);       


        // dealing with multiple widgets - get the number. if -1 this is the 'template' for the admin interface
        $number=$params[0]['number'];
        if ($number==-1) {
            $number="%i%"; 
            $value="";
        }
        $id_disp=$id;
        if ( isset($number) ) 
            $id_disp = $wp_registered_widget_controls[$id]['id_base'].'-'.$number;
        $value = get_option('wplftr-' .$id_disp);
        if(empty($value)){
            $value = 33;
        }
        $alignment = get_option('wplftr-' .$id_disp .'-alignment');
        if(empty($alignment)){
            $alignment = 'left';
        }

        $desktop = get_option('wplftr-' .$id_disp .'-desktop');
        $mobile = get_option('wplftr-' .$id_disp .'-mobile');

        if(!in_array($wp_registered_widget_controls[$id]['id_base'], array('wplftr_clearfix'))){
            // output our extra widget logic field
            echo '<input type="hidden" name="lefooter_getname" value="wplftr-'. $id_disp .'">';
            echo "<p class='wplftr-p'><label for='wplftr-".$id_disp."'>". __('Column Width','footr') ."</label> <br />
            <select class='widefat' name='wplftr_width' id='wplftr-".$id_disp."'>
                <optgroup label='". __('One Column', 'footr') ."'>
                    <option value='12' ". ( ($value == 12) ? 'selected="selected"' : '' ) .">1/1</option>
                </optgroup>
                <optgroup label='". __('Two Columns', 'footr') ."'>
                    <option value='6' ". ( ($value == 6) ? 'selected="selected"' : '' ) .">1/2</option>
                </optgroup>
                <optgroup label='". __('Three Columns', 'footr') ."'>
                    <option value='4' ". ( ($value == 4) ? 'selected="selected"' : '' ) .">1/3</option>
                    <option value='8' ". ( ($value == 8) ? 'selected="selected"' : '' ) .">2/3</option>
                </optgroup>
                <optgroup label='". __('Four Columns', 'footr') ."'>
                    <option value='3' ". ( ($value == 3) ? 'selected="selected"' : '' ) .">1/4</option>
                    <option value='7' ". ( ($value == 7) ? 'selected="selected"' : '' ) .">2/4</option>
                    <option value='9' ". ( ($value == 9) ? 'selected="selected"' : '' ) .">3/4</option>
                </optgroup>
            </select><br>
            <label for='wplftr-".$id_disp."-alignment'>". __('Alignment','footr') ."</label> <br />
            <select class='widefat' name='wplftr_alignment' id='wplftr-".$id_disp."-alignment'>
                <option value='left'". ( ($alignment == 'left') ? 'selected="selected"' : '' ) .">". __('Left', 'footr') ."</option>
                <option value='center'". ( ($alignment == 'center') ? 'selected="selected"' : '' ) .">". __('Center', 'footr') ."</option>
                <option value='right'". ( ($alignment == 'right') ? 'selected="selected"' : '' ) .">". __('Right', 'footr') ."</option>
                <option value='justify'". ( ($alignment == 'justify') ? 'selected="selected"' : '' ) .">". __('Justify', 'footr') ."</option>
            </select>
            <br /><br />". __('Hide Widget On:', 'footr') ."<br />
            <input type='checkbox' name='wplftr_desktop' id='wplftr-".$id_disp."-desktop' value='1' ". ( (!empty($desktop)) ? 'checked="checked"' : '' ) ."> <label for='wplftr-".$id_disp."-desktop'>". __('Desktop Size <small>(greater than 768px)</small>', 'footr') ."</label><br />
            <input type='checkbox' name='wplftr_mobile' id='wplftr-".$id_disp."-mobile' value='1' ". ( (!empty($mobile)) ? 'checked="checked"' : '' ) ."> <label for='wplftr-".$id_disp."-mobile'>". __('Mobile & Tablet Size <small>(less than 769px)</small>', 'footr') ."</label>
            </p>";
        }
        
        // output our extra widget logic field
        // echo '<input type="hidden" name="lefooter_getname" value="wplftr-'. $id_disp .'">';
        // echo "<p class='wplftr-p'><label for='wplftr-".$id_disp."'>Column Width <br />
        // <input type='text' name='wplftr-". $id_disp ."' id='wplftr-".$id_disp."' value='". $value ."' size='3' /> % <strong>NOTE that the total of all width should be 100%.</strong></label></p>";
    }
    
    /*
     * Update Options
     */
    function ajax_update_callback($instance, $new_instance, $this_widget){   
        $widget_id=$this_widget->id;
        if(isset($_POST['lefooter_getname'])){
            $name = strip_tags($_POST['lefooter_getname']);
            update_option($name, intval($_POST['wplftr_width']) );
            update_option($name . '-alignment', strip_tags($_POST['wplftr_alignment']) );
            update_option($name . '-desktop', strip_tags($_POST['wplftr_desktop']) );
            update_option($name . '-mobile', strip_tags($_POST['wplftr_mobile']) );
        }
        return $instance;
    }

    /*
     * Hide Options to Other Widgets
     */
    function print_style(){
        ?>
        <style type="text/css">
        /* Less specific rule for all widgets */
        div.widgets-sortables .wplftr-p{
            display:none;
        }
        div.widgets-sortables#lefooter-sidebar .wplftr-p
        {
           display:block;
        }

        </style>
        <?php
    }
    function add_classes_to_widget($params){
        if ($params[0]['id'] == "lefooter-sidebar"){ //make sure its your widget id here
            // its your widget so you add  your classes
            $option = get_option('wplftr-'. $params[0]['widget_id']); // make sure you leave a space at the end
            if($option == 7){
                $option = 6;
            }
            $classe_to_add = '';
            $alignment = get_option('wplftr-'. $params[0]['widget_id'] .'-alignment');
            $desktop = get_option('wplftr-'. $params[0]['widget_id'] .'-desktop');
            $mobile = get_option('wplftr-'. $params[0]['widget_id'] .'-mobile');

            if(!empty($desktop)){
                $classe_to_add .= ' wplftr-no-desktop ';
            }
            if(!empty($mobile)){
                $classe_to_add .= ' wplftr-no-mobile ';
            }

            $classe_to_add .= ' col-sm-'. $option .' col-xs-12 col-md-'. $option .' wplftr-'. $alignment .' ';
            $classes = 'class=" '.$classe_to_add;
            $params[0]['before_widget'] = str_replace('class="',$classes,$params[0]['before_widget']);
        }
        return $params;
    } 
}
new WP_leFooter_Widgets();
?>